@@ -26,12 +26,13 @@
  */
 
 #include "config.h"
-#include "asc-image.h"
+#include "asc-image-private.h"
 
 #include <gio/gio.h>
 #include <math.h>
 
 #include "asc-globals.h"
+#include "asc-canvas.h"
 
 struct _AscImage {
 	GObject parent_instance;
@@ -39,8 +40,8 @@ struct _AscImage {
 
 typedef struct {
 	GdkPixbuf *pix;
-	guint width;
-	guint height;
+	gint width;
+	gint height;
 } AscImagePrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE (AscImage, asc_image, G_TYPE_OBJECT)
@@ -73,20 +74,24 @@ asc_image_format_to_string (AscImageFormat format)
 {
 	if (format == ASC_IMAGE_FORMAT_PNG)
 		return "png";
-	if (format == ASC_IMAGE_FORMAT_JPEG)
-		return "jpeg";
-	if (format == ASC_IMAGE_FORMAT_GIF)
-		return "gif";
+	if (format == ASC_IMAGE_FORMAT_JXL)
+		return "jxl";
+	if (format == ASC_IMAGE_FORMAT_AVIF)
+		return "avif";
+	if (format == ASC_IMAGE_FORMAT_WEBP)
+		return "webp";
 	if (format == ASC_IMAGE_FORMAT_SVG)
 		return "svg";
 	if (format == ASC_IMAGE_FORMAT_SVGZ)
 		return "svgz";
-	if (format == ASC_IMAGE_FORMAT_WEBP)
-		return "webp";
-	if (format == ASC_IMAGE_FORMAT_AVIF)
-		return "avif";
+	if (format == ASC_IMAGE_FORMAT_JPEG)
+		return "jpeg";
+	if (format == ASC_IMAGE_FORMAT_GIF)
+		return "gif";
+
 	if (format == ASC_IMAGE_FORMAT_XPM)
 		return "xpm";
+
 	return NULL;
 }
 
@@ -103,20 +108,23 @@ asc_image_format_from_string (const gchar *str)
 {
 	if (g_strcmp0 (str, "png") == 0)
 		return ASC_IMAGE_FORMAT_PNG;
-	if (g_strcmp0 (str, "jpeg") == 0)
-		return ASC_IMAGE_FORMAT_JPEG;
-	if (g_strcmp0 (str, "gif") == 0)
-		return ASC_IMAGE_FORMAT_GIF;
+	if (g_strcmp0 (str, "jxl") == 0)
+		return ASC_IMAGE_FORMAT_JXL;
+	if (g_strcmp0 (str, "avif") == 0)
+		return ASC_IMAGE_FORMAT_AVIF;
+	if (g_strcmp0 (str, "webp") == 0)
+		return ASC_IMAGE_FORMAT_WEBP;
 	if (g_strcmp0 (str, "svg") == 0)
 		return ASC_IMAGE_FORMAT_SVG;
 	if (g_strcmp0 (str, "svgz") == 0)
 		return ASC_IMAGE_FORMAT_SVGZ;
-	if (g_strcmp0 (str, "webp") == 0)
-		return ASC_IMAGE_FORMAT_WEBP;
-	if (g_strcmp0 (str, "avif") == 0)
-		return ASC_IMAGE_FORMAT_AVIF;
+	if (g_strcmp0 (str, "jpeg") == 0)
+		return ASC_IMAGE_FORMAT_JPEG;
+	if (g_strcmp0 (str, "gif") == 0)
+		return ASC_IMAGE_FORMAT_GIF;
 	if (g_strcmp0 (str, "xpm") == 0)
 		return ASC_IMAGE_FORMAT_XPM;
+
 	return ASC_IMAGE_FORMAT_UNKNOWN;
 }
 
@@ -135,20 +143,23 @@ asc_image_format_from_filename (const gchar *fname)
 
 	if (g_str_has_suffix (fname_low, ".png"))
 		return ASC_IMAGE_FORMAT_PNG;
-	if (g_str_has_suffix (fname_low, ".jpeg") || g_str_has_suffix (fname_low, ".jpg"))
-		return ASC_IMAGE_FORMAT_JPEG;
-	if (g_str_has_suffix (fname_low, ".gif"))
-		return ASC_IMAGE_FORMAT_GIF;
+	if (g_str_has_suffix (fname_low, ".jxl"))
+		return ASC_IMAGE_FORMAT_JXL;
+	if (g_str_has_suffix (fname_low, ".avif"))
+		return ASC_IMAGE_FORMAT_AVIF;
+	if (g_str_has_suffix (fname_low, ".webp"))
+		return ASC_IMAGE_FORMAT_WEBP;
 	if (g_str_has_suffix (fname_low, ".svg"))
 		return ASC_IMAGE_FORMAT_SVG;
 	if (g_str_has_suffix (fname_low, ".svgz"))
 		return ASC_IMAGE_FORMAT_SVGZ;
-	if (g_str_has_suffix (fname_low, ".webp"))
-		return ASC_IMAGE_FORMAT_WEBP;
-	if (g_str_has_suffix (fname_low, ".avif"))
-		return ASC_IMAGE_FORMAT_AVIF;
+	if (g_str_has_suffix (fname_low, ".jpeg") || g_str_has_suffix (fname_low, ".jpg"))
+		return ASC_IMAGE_FORMAT_JPEG;
+	if (g_str_has_suffix (fname_low, ".gif"))
+		return ASC_IMAGE_FORMAT_GIF;
 	if (g_str_has_suffix (fname_low, ".xpm"))
 		return ASC_IMAGE_FORMAT_XPM;
+
 	return ASC_IMAGE_FORMAT_UNKNOWN;
 }
 
@@ -284,21 +295,22 @@ asc_image_supported_format_names (void)
 static gboolean
 asc_image_load_pixbuf (AscImage *image,
 		       GdkPixbuf *pixbuf,
-		       guint dest_size,
-		       guint src_size_min,
+		       gint dest_width,
+		       gint dest_height,
+		       gint src_size_min,
 		       AscImageLoadFlags flags,
 		       GError **error)
 {
-	guint pixbuf_height;
-	guint pixbuf_width;
-	guint tmp_height;
-	guint tmp_width;
+	gint pixbuf_height;
+	gint pixbuf_width;
+	gint tmp_height;
+	gint tmp_width;
 	g_autoptr(GdkPixbuf) pixbuf_tmp = NULL;
 	g_autoptr(GdkPixbuf) pixbuf_new = NULL;
 
 	/* check size */
-	if (gdk_pixbuf_get_width (pixbuf) < (gint) src_size_min &&
-	    gdk_pixbuf_get_height (pixbuf) < (gint) src_size_min) {
+	if (gdk_pixbuf_get_width (pixbuf) < src_size_min &&
+	    gdk_pixbuf_get_height (pixbuf) < src_size_min) {
 		g_set_error (error,
 			     ASC_IMAGE_ERROR,
 			     ASC_IMAGE_ERROR_FAILED,
@@ -309,9 +321,9 @@ asc_image_load_pixbuf (AscImage *image,
 	}
 
 	/* don't do anything to an icon with the perfect size */
-	pixbuf_width = (guint) gdk_pixbuf_get_width (pixbuf);
-	pixbuf_height = (guint) gdk_pixbuf_get_height (pixbuf);
-	if (pixbuf_width == dest_size && pixbuf_height == dest_size) {
+	pixbuf_width = gdk_pixbuf_get_width (pixbuf);
+	pixbuf_height = gdk_pixbuf_get_height (pixbuf);
+	if (pixbuf_width == dest_width && pixbuf_height == dest_height) {
 		asc_image_set_pixbuf (image, pixbuf);
 		return TRUE;
 	}
@@ -320,25 +332,21 @@ asc_image_load_pixbuf (AscImage *image,
 	 * good as icons are properly aligned in the UI layout */
 	if (as_flags_contains (flags, ASC_IMAGE_LOAD_FLAG_ALWAYS_RESIZE)) {
 		pixbuf_new = gdk_pixbuf_scale_simple (pixbuf,
-						      (gint) dest_size,
-						      (gint) dest_size,
+						      dest_width,
+						      dest_height,
 						      GDK_INTERP_HYPER);
 		asc_image_set_pixbuf (image, pixbuf_new);
 		return TRUE;
 	}
 
 	/* never scale up, just pad */
-	if (pixbuf_width < dest_size && pixbuf_height < dest_size) {
-		g_debug ("icon padded to %ux%u as size %ux%u",
-			 dest_size,
-			 dest_size,
+	if (pixbuf_width < dest_width && pixbuf_height < dest_height) {
+		g_debug ("Image padded to %dx%d as size %dx%d",
+			 dest_width,
+			 dest_height,
 			 pixbuf_width,
 			 pixbuf_height);
-		pixbuf_new = gdk_pixbuf_new (GDK_COLORSPACE_RGB,
-					     TRUE,
-					     8,
-					     (gint) dest_size,
-					     (gint) dest_size);
+		pixbuf_new = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, dest_width, dest_height);
 		gdk_pixbuf_fill (pixbuf_new, 0x00000000);
 		gdk_pixbuf_copy_area (pixbuf,
 				      0,
@@ -346,8 +354,8 @@ asc_image_load_pixbuf (AscImage *image,
 				      (gint) pixbuf_width,
 				      (gint) pixbuf_height,
 				      pixbuf_new,
-				      (gint) (dest_size - pixbuf_width) / 2,
-				      (gint) (dest_size - pixbuf_height) / 2);
+				      (dest_width - pixbuf_width) / 2,
+				      (dest_height - pixbuf_height) / 2);
 		asc_image_set_pixbuf (image, pixbuf_new);
 		return TRUE;
 	}
@@ -355,26 +363,22 @@ asc_image_load_pixbuf (AscImage *image,
 	/* is the aspect ratio perfectly square */
 	if (pixbuf_width == pixbuf_height) {
 		pixbuf_new = gdk_pixbuf_scale_simple (pixbuf,
-						      (gint) dest_size,
-						      (gint) dest_size,
+						      dest_width,
+						      dest_height,
 						      GDK_INTERP_HYPER);
 		asc_image_set_pixbuf (image, pixbuf_new);
 		return TRUE;
 	}
 
 	/* create new square pixbuf with alpha padding */
-	pixbuf_new = gdk_pixbuf_new (GDK_COLORSPACE_RGB,
-				     TRUE,
-				     8,
-				     (gint) dest_size,
-				     (gint) dest_size);
+	pixbuf_new = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, dest_width, dest_height);
 	gdk_pixbuf_fill (pixbuf_new, 0x00000000);
 	if (pixbuf_width > pixbuf_height) {
-		tmp_width = dest_size;
-		tmp_height = dest_size * pixbuf_height / pixbuf_width;
+		tmp_width = dest_width;
+		tmp_height = dest_height * pixbuf_height / pixbuf_width;
 	} else {
-		tmp_width = dest_size * pixbuf_width / pixbuf_height;
-		tmp_height = dest_size;
+		tmp_width = dest_width * pixbuf_width / pixbuf_height;
+		tmp_height = dest_height;
 	}
 	pixbuf_tmp = gdk_pixbuf_scale_simple (pixbuf,
 					      (gint) tmp_width,
@@ -388,8 +392,8 @@ asc_image_load_pixbuf (AscImage *image,
 			      (gint) tmp_width,
 			      (gint) tmp_height,
 			      pixbuf_new,
-			      (gint) (dest_size - tmp_width) / 2,
-			      (gint) (dest_size - tmp_height) / 2);
+			      (dest_width - tmp_width) / 2,
+			      (dest_height - tmp_height) / 2);
 	asc_image_set_pixbuf (image, pixbuf_new);
 	return TRUE;
 }
@@ -397,7 +401,8 @@ asc_image_load_pixbuf (AscImage *image,
 /**
  * asc_image_new_from_file:
  * @fname: Name of the file to load.
- * @dest_size: The size of the constructed pixbuf, or 0 for the native size
+ * @dest_width: The suggested width of the constructed pixbuf, or 0 for the native size
+ * @dest_height: The suggested height of the constructed pixbuf, or 0 for the native size
  * @flags: a #AscImageLoadFlags, e.g. %ASC_IMAGE_LOAD_FLAG_NONE
  * @error: A #GError or %NULL
  *
@@ -405,14 +410,15 @@ asc_image_load_pixbuf (AscImage *image,
  **/
 AscImage *
 asc_image_new_from_file (const gchar *fname,
-			 guint dest_size,
+			 gint dest_width,
+			 gint dest_height,
 			 AscImageLoadFlags flags,
 			 GError **error)
 {
 	gboolean ret;
 	g_autoptr(AscImage) image = asc_image_new ();
 
-	ret = asc_image_load_filename (image, fname, dest_size, 0, flags, error);
+	ret = asc_image_load_filename (image, fname, dest_width, dest_height, 0, flags, error);
 	if (!ret)
 		return NULL;
 	return g_steal_pointer (&image);
@@ -422,9 +428,10 @@ asc_image_new_from_file (const gchar *fname,
  * asc_image_new_from_data:
  * @data: Data to load.
  * @len: Length of the data to load.
- * @dest_size: The size of the constructed pixbuf, or 0 for the native size
+ * @dest_width: The suggested width of the constructed pixbuf, or 0 for the native size
+ * @dest_height: The suggested height of the constructed pixbuf, or 0 for the native size
  * @flags: a #AscImageLoadFlags, e.g. %ASC_IMAGE_LOAD_FLAG_NONE
- * @compressed: %TRUE if passed data is gzip-compressed
+ * @format_hint: Assume the specified image format for data, use %ASC_IMAGE_FORMAT_UNKNOWN to guess.
  * @error: A #GError or %NULL
  *
  * Creates a new #AscImage from data in memory.
@@ -432,9 +439,10 @@ asc_image_new_from_file (const gchar *fname,
 AscImage *
 asc_image_new_from_data (const void *data,
 			 gssize len,
-			 guint dest_size,
-			 gboolean compressed,
+			 gint dest_width,
+			 gint dest_height,
 			 AscImageLoadFlags flags,
+			 AscImageFormat format_hint,
 			 GError **error)
 {
 	gboolean ret;
@@ -445,14 +453,14 @@ asc_image_new_from_data (const void *data,
 	g_autoptr(AscImage) image = asc_image_new ();
 
 	istream = g_memory_input_stream_new_from_data (data, len, NULL);
-	if (compressed) {
+	if (format_hint == ASC_IMAGE_FORMAT_SVGZ) {
 		conv = G_CONVERTER (g_zlib_decompressor_new (G_ZLIB_COMPRESSOR_FORMAT_GZIP));
 		dstream = g_converter_input_stream_new (istream, conv);
 	} else {
 		dstream = g_object_ref (istream);
 	}
 
-	if (dest_size == 0) {
+	if (dest_width <= 0 && dest_height <= 0) {
 		/* use the native size and don't perform any scaling */
 		pix = gdk_pixbuf_new_from_stream (dstream, NULL, error);
 		if (pix == NULL)
@@ -465,8 +473,8 @@ asc_image_new_from_data (const void *data,
 	/* load & scale */
 	if (as_flags_contains (flags, ASC_IMAGE_LOAD_FLAG_ALWAYS_RESIZE)) {
 		pix = gdk_pixbuf_new_from_stream_at_scale (dstream,
-							   dest_size,
-							   dest_size,
+							   dest_width,
+							   dest_height,
 							   TRUE,
 							   NULL,
 							   error);
@@ -478,7 +486,7 @@ asc_image_new_from_data (const void *data,
 		if (pix == NULL)
 			return NULL;
 	}
-	ret = asc_image_load_pixbuf (image, pix, dest_size, 0, flags, error);
+	ret = asc_image_load_pixbuf (image, pix, dest_width, dest_height, 0, flags, error);
 	if (!ret)
 		return NULL;
 
@@ -546,8 +554,9 @@ asc_image_pixbuf_new_from_gz (const gchar *filename, gint width, gint height, GE
  * asc_image_load_filename:
  * @image: a #AscImage instance.
  * @filename: filename to read from
- * @dest_size: The size of the constructed pixbuf, or 0 for the native size
- * @src_size_min: The smallest source size allowed, or 0 for none
+ * @dest_width: The suggested width of the constructed pixbuf, or 0 for the native size
+ * @dest_height: The suggested height of the constructed pixbuf, or 0 for the native size
+ * @src_size_min: The smallest source size (width or height) allowed, or 0 for no limit
  * @flags: a #AscImageLoadFlags, e.g. %ASC_IMAGE_LOAD_FLAG_NONE
  * @error: A #GError or %NULL.
  *
@@ -558,8 +567,9 @@ asc_image_pixbuf_new_from_gz (const gchar *filename, gint width, gint height, GE
 gboolean
 asc_image_load_filename (AscImage *image,
 			 const gchar *filename,
-			 guint dest_size,
-			 guint src_size_min,
+			 gint dest_width,
+			 gint dest_height,
+			 gint src_size_min,
 			 AscImageLoadFlags flags,
 			 GError **error)
 {
@@ -591,7 +601,7 @@ asc_image_load_filename (AscImage *image,
 		if (fmt == NULL) {
 			g_set_error_literal (error,
 					     ASC_IMAGE_ERROR,
-					     ASC_IMAGE_ERROR_FAILED,
+					     ASC_IMAGE_ERROR_UNSUPPORTED,
 					     "Image format was not recognized");
 			return FALSE;
 		}
@@ -607,9 +617,9 @@ asc_image_load_filename (AscImage *image,
 	}
 
 	/* load the image of the native size */
-	if (dest_size == 0) {
+	if (dest_width <= 0 && dest_height <= 0) {
 		g_autoptr(GdkPixbuf) pixbuf = NULL;
-		pixbuf = asc_image_pixbuf_new_from_gz (filename, 0, 0, error);
+		pixbuf = asc_image_pixbuf_new_from_gz (filename, -1, -1, error);
 		if (pixbuf == NULL)
 			return FALSE;
 		asc_image_set_pixbuf (image, pixbuf);
@@ -619,8 +629,8 @@ asc_image_load_filename (AscImage *image,
 	/* open file in native size */
 	if (is_svg) {
 		pixbuf_src = asc_image_pixbuf_new_from_gz (filename,
-							   (gint) dest_size,
-							   (gint) dest_size,
+							   (gint) dest_width,
+							   (gint) dest_height,
 							   error);
 	} else {
 		pixbuf_src = asc_image_pixbuf_new_from_gz (filename, 0, 0, error);
@@ -629,7 +639,13 @@ asc_image_load_filename (AscImage *image,
 		return FALSE;
 
 	/* create from pixbuf & resize */
-	return asc_image_load_pixbuf (image, pixbuf_src, dest_size, src_size_min, flags, error);
+	return asc_image_load_pixbuf (image,
+				      pixbuf_src,
+				      dest_width,
+				      dest_height,
+				      src_size_min,
+				      flags,
+				      error);
 }
 
 /**
@@ -664,8 +680,8 @@ asc_image_set_pixbuf (AscImage *image, GdkPixbuf *pixbuf)
 	g_set_object (&priv->pix, pixbuf);
 	if (pixbuf == NULL)
 		return;
-	priv->width = (guint) gdk_pixbuf_get_width (pixbuf);
-	priv->height = (guint) gdk_pixbuf_get_height (pixbuf);
+	priv->width = gdk_pixbuf_get_width (pixbuf);
+	priv->height = gdk_pixbuf_get_height (pixbuf);
 }
 
 /**
@@ -674,7 +690,7 @@ asc_image_set_pixbuf (AscImage *image, GdkPixbuf *pixbuf)
  *
  * Gets the image width.
  **/
-guint
+gint
 asc_image_get_width (AscImage *image)
 {
 	AscImagePrivate *priv = GET_PRIVATE (image);
@@ -687,7 +703,7 @@ asc_image_get_width (AscImage *image)
  *
  * Gets the image height.
  **/
-guint
+gint
 asc_image_get_height (AscImage *image)
 {
 	AscImagePrivate *priv = GET_PRIVATE (image);
@@ -703,12 +719,13 @@ asc_image_get_height (AscImage *image)
  * Scale the image to the given size.
  **/
 void
-asc_image_scale (AscImage *image, guint new_width, guint new_height)
+asc_image_scale (AscImage *image, gint new_width, gint new_height)
 {
 	AscImagePrivate *priv = GET_PRIVATE (image);
 	g_autoptr(GdkPixbuf) res_pix = NULL;
-	if (priv->pix == NULL)
-		return;
+
+	g_return_if_fail (new_width > 0 && new_height > 0);
+	g_return_if_fail (priv->pix != NULL);
 
 	res_pix = gdk_pixbuf_scale_simple (priv->pix, new_width, new_height, GDK_INTERP_BILINEAR);
 	if (res_pix == NULL)
@@ -727,10 +744,13 @@ asc_image_scale (AscImage *image, guint new_width, guint new_height)
  * its aspect ratio.
  **/
 void
-asc_image_scale_to_width (AscImage *image, guint new_width)
+asc_image_scale_to_width (AscImage *image, gint new_width)
 {
 	double scale;
-	guint new_height;
+	gint new_height;
+
+	g_return_if_fail (new_width > 0);
+
 	scale = (double) new_width / (double) asc_image_get_width (image);
 	new_height = floor (asc_image_get_height (image) * scale);
 
@@ -746,10 +766,13 @@ asc_image_scale_to_width (AscImage *image, guint new_width)
  * its aspect ratio.
  **/
 void
-asc_image_scale_to_height (AscImage *image, guint new_height)
+asc_image_scale_to_height (AscImage *image, gint new_height)
 {
 	double scale;
-	guint new_width;
+	gint new_width;
+
+	g_return_if_fail (new_height > 0);
+
 	scale = (double) new_height / (double) asc_image_get_height (image);
 	new_width = floor (asc_image_get_width (image) * scale);
 
@@ -765,14 +788,70 @@ asc_image_scale_to_height (AscImage *image, guint new_height)
  * and keep its aspect ratio.
  **/
 void
-asc_image_scale_to_fit (AscImage *image, guint size)
+asc_image_scale_to_fit (AscImage *image, gint size)
 {
+	g_return_if_fail (size > 0);
 	if (asc_image_get_height (image) > asc_image_get_width (image))
 		asc_image_scale_to_height (image, size);
 	else
 		asc_image_scale_to_width (image, size);
 }
 
+/**
+ * asc_render_svg_to_file:
+ * @stream: Input stream with SVG data.
+ * @width: Target width.
+ * @height: Target height.
+ * @format: Target image format, e.g. %ASC_IMAGE_FORMAT_PNG
+ * @filename: Filename to write to.
+ * @error: A #GError or %NULL
+ *
+ * Renders SVG data from a stream to a file in a specific format.
+ *
+ * Returns: %TRUE for success
+ **/
+gboolean
+asc_render_svg_to_file (GInputStream *stream,
+			gint width,
+			gint height,
+			AscImageFormat format,
+			const gchar *filename,
+			GError **error)
+{
+	g_autoptr(AscCanvas) cv = NULL;
+	g_autoptr(GdkPixbuf) pixbuf = NULL;
+
+	g_return_val_if_fail (width > 0 && height > 0, FALSE);
+
+	if (format == ASC_IMAGE_FORMAT_UNKNOWN) {
+		g_set_error (error,
+			     ASC_IMAGE_ERROR,
+			     ASC_IMAGE_ERROR_UNSUPPORTED,
+			     "Unknown image format specified");
+		return FALSE;
+	}
+	if (format == ASC_IMAGE_FORMAT_SVG || format == ASC_IMAGE_FORMAT_SVGZ) {
+		g_set_error (error,
+			     ASC_IMAGE_ERROR,
+			     ASC_IMAGE_ERROR_UNSUPPORTED,
+			     "Can not render existing SVG data to SVG");
+		return FALSE;
+	}
+
+	cv = asc_canvas_new (width, height);
+	if (!asc_canvas_render_svg (cv, stream, error))
+		return FALSE;
+
+	if (format == ASC_IMAGE_FORMAT_PNG) {
+		/* we can just save that PNG directly */
+		return asc_canvas_save_png (cv, filename, error);
+	}
+
+	/* save to other formats */
+	pixbuf = asc_canvas_to_pixbuf (cv);
+	return gdk_pixbuf_save (pixbuf, filename, asc_image_format_to_string (format), error, NULL);
+}
+
 /**
  * asc_image_save_pixbuf:
  * @image: a #AscImage instance.
@@ -785,14 +864,14 @@ asc_image_scale_to_fit (AscImage *image, guint size)
  * Returns: (transfer full): A #GdkPixbuf of the specified size
  **/
 GdkPixbuf *
-asc_image_save_pixbuf (AscImage *image, guint width, guint height, AscImageSaveFlags flags)
+asc_image_save_pixbuf (AscImage *image, gint width, gint height, AscImageSaveFlags flags)
 {
 	AscImagePrivate *priv = GET_PRIVATE (image);
 	GdkPixbuf *pixbuf = NULL;
-	guint tmp_height;
-	guint tmp_width;
-	guint pixbuf_height;
-	guint pixbuf_width;
+	gint tmp_height;
+	gint tmp_width;
+	gint pixbuf_height;
+	gint pixbuf_width;
 	g_autoptr(GdkPixbuf) pixbuf_tmp = NULL;
 
 	g_return_val_if_fail (ASC_IS_IMAGE (image), NULL);
@@ -802,23 +881,20 @@ asc_image_save_pixbuf (AscImage *image, guint width, guint height, AscImageSaveF
 		return NULL;
 
 	/* 0 means 'default' */
-	if (width == 0)
-		width = (guint) gdk_pixbuf_get_width (priv->pix);
-	if (height == 0)
-		height = (guint) gdk_pixbuf_get_height (priv->pix);
+	if (width <= 0)
+		width = gdk_pixbuf_get_width (priv->pix);
+	if (height <= 0)
+		height = gdk_pixbuf_get_height (priv->pix);
 
 	/* don't do anything to an image with the correct size */
-	pixbuf_width = (guint) gdk_pixbuf_get_width (priv->pix);
-	pixbuf_height = (guint) gdk_pixbuf_get_height (priv->pix);
+	pixbuf_width = gdk_pixbuf_get_width (priv->pix);
+	pixbuf_height = gdk_pixbuf_get_height (priv->pix);
 	if (width == pixbuf_width && height == pixbuf_height)
 		return g_object_ref (priv->pix);
 
 	/* is the aspect ratio of the source perfectly 16:9 */
 	if (flags == ASC_IMAGE_SAVE_FLAG_NONE || (pixbuf_width / 16) * 9 == pixbuf_height) {
-		pixbuf = gdk_pixbuf_scale_simple (priv->pix,
-						  (gint) width,
-						  (gint) height,
-						  GDK_INTERP_HYPER);
+		pixbuf = gdk_pixbuf_scale_simple (priv->pix, width, height, GDK_INTERP_HYPER);
 		if (as_flags_contains (flags, ASC_IMAGE_SAVE_FLAG_SHARPEN))
 			asc_pixbuf_sharpen (pixbuf, 1, -0.5);
 		if (as_flags_contains (flags, ASC_IMAGE_SAVE_FLAG_BLUR))
@@ -827,7 +903,7 @@ asc_image_save_pixbuf (AscImage *image, guint width, guint height, AscImageSaveF
 	}
 
 	/* create new 16:9 pixbuf with alpha padding */
-	pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, (gint) width, (gint) height);
+	pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, width, height);
 	gdk_pixbuf_fill (pixbuf, 0x00000000);
 	/* check the ratio to see which property needs to be fitted and which needs
 	 * to be reduced */
@@ -838,10 +914,7 @@ asc_image_save_pixbuf (AscImage *image, guint width, guint height, AscImageSaveF
 		tmp_width = height * pixbuf_width / pixbuf_height;
 		tmp_height = height;
 	}
-	pixbuf_tmp = gdk_pixbuf_scale_simple (priv->pix,
-					      (gint) tmp_width,
-					      (gint) tmp_height,
-					      GDK_INTERP_HYPER);
+	pixbuf_tmp = gdk_pixbuf_scale_simple (priv->pix, tmp_width, tmp_height, GDK_INTERP_HYPER);
 	if (as_flags_contains (flags, ASC_IMAGE_SAVE_FLAG_SHARPEN))
 		asc_pixbuf_sharpen (pixbuf_tmp, 1, -0.5);
 	if (as_flags_contains (flags, ASC_IMAGE_SAVE_FLAG_BLUR))
@@ -849,11 +922,11 @@ asc_image_save_pixbuf (AscImage *image, guint width, guint height, AscImageSaveF
 	gdk_pixbuf_copy_area (pixbuf_tmp,
 			      0,
 			      0, /* of src */
-			      (gint) tmp_width,
-			      (gint) tmp_height,
+			      tmp_width,
+			      tmp_height,
 			      pixbuf,
-			      (gint) (width - tmp_width) / 2,
-			      (gint) (height - tmp_height) / 2);
+			      (width - tmp_width) / 2,
+			      (height - tmp_height) / 2);
 	return pixbuf;
 }
 
@@ -873,8 +946,8 @@ asc_image_save_pixbuf (AscImage *image, guint width, guint height, AscImageSaveF
 gboolean
 asc_image_save_filename (AscImage *image,
 			 const gchar *filename,
-			 guint width,
-			 guint height,
+			 gint width,
+			 gint height,
 			 AscImageSaveFlags flags,
 			 GError **error)
 {
