@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2016-2022 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2016-2024 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -46,8 +46,11 @@
  *
  * Returns: (transfer full): A new #AsComponent or %NULL if we refused to accept this data.
  **/
-AsComponent*
-asc_parse_metainfo_data (AscResult *cres, AsMetadata *mdata, GBytes *bytes, const gchar *mi_basename)
+AsComponent *
+asc_parse_metainfo_data (AscResult *cres,
+			 AsMetadata *mdata,
+			 GBytes *bytes,
+			 const gchar *mi_basename)
 {
 	g_autoptr(GError) error = NULL;
 	AsComponent *cpt;
@@ -55,11 +58,24 @@ asc_parse_metainfo_data (AscResult *cres, AsMetadata *mdata, GBytes *bytes, cons
 	g_return_val_if_fail (mi_basename != NULL, NULL);
 
 	if (!as_metadata_parse_bytes (mdata, bytes, AS_FORMAT_KIND_XML, &error)) {
-		asc_result_add_hint (cres, NULL,
-				     "ancient-metadata",
-				     "fname", mi_basename,
-				     "error", error->message,
-				     NULL);
+		g_autofree gchar *cid_guess = g_strdup (mi_basename);
+
+		/* try to guess the component-ID */
+		if (g_str_has_suffix (cid_guess, ".metainfo.xml"))
+			cid_guess[strlen (cid_guess) - 13] = '\0';
+		else if (g_str_has_suffix (cid_guess, ".appdata.xml"))
+			cid_guess[strlen (cid_guess) - 12] = '\0';
+		else if (g_str_has_suffix (cid_guess, ".xml"))
+			cid_guess[strlen (cid_guess) - 4] = '\0';
+
+		asc_result_add_hint_by_cid (cres,
+					    cid_guess,
+					    "metainfo-parsing-error",
+					    "fname",
+					    mi_basename,
+					    "error",
+					    error->message,
+					    NULL);
 		return NULL;
 	}
 
@@ -69,10 +85,7 @@ asc_parse_metainfo_data (AscResult *cres, AsMetadata *mdata, GBytes *bytes, cons
 
 	/* check if we have a component-id, a component without ID is invalid */
 	if (as_is_empty (as_component_get_id (cpt))) {
-		asc_result_add_hint (cres, NULL,
-				     "metainfo-no-id",
-				     "fname", mi_basename,
-				     NULL);
+		asc_result_add_hint (cres, NULL, "metainfo-no-id", "fname", mi_basename, NULL);
 		return NULL;
 	}
 
@@ -82,9 +95,11 @@ asc_parse_metainfo_data (AscResult *cres, AsMetadata *mdata, GBytes *bytes, cons
 
 	/* check if we can actually legally use this metadata */
 	if (!as_license_is_metadata_license (as_component_get_metadata_license (cpt))) {
-		asc_result_add_hint (cres, cpt,
+		asc_result_add_hint (cres,
+				     cpt,
 				     "metainfo-license-invalid",
-				     "license", as_component_get_metadata_license (cpt),
+				     "license",
+				     as_component_get_metadata_license (cpt),
 				     NULL);
 		return NULL;
 	}
@@ -109,7 +124,7 @@ asc_parse_metainfo_data (AscResult *cres, AsMetadata *mdata, GBytes *bytes, cons
  *
  * Returns: (transfer full): A new #AsComponent or %NULL if we refused to accept this data.
  **/
-AsComponent*
+AsComponent *
 asc_parse_metainfo_data_simple (AscResult *cres, GBytes *bytes, const gchar *mi_basename)
 {
 	g_autoptr(AsMetadata) mdata = as_metadata_new ();
@@ -117,10 +132,7 @@ asc_parse_metainfo_data_simple (AscResult *cres, GBytes *bytes, const gchar *mi_
 	as_metadata_set_locale (mdata, "ALL");
 	as_metadata_set_format_style (mdata, AS_FORMAT_STYLE_METAINFO);
 
-	return asc_parse_metainfo_data (cres,
-					mdata,
-					bytes,
-					mi_basename);
+	return asc_parse_metainfo_data (cres, mdata, bytes, mi_basename);
 }
 
 /**
@@ -148,22 +160,26 @@ asc_process_metainfo_releases (AscResult *cres,
 {
 	g_autoptr(GError) local_error = NULL;
 	g_autoptr(GBytes) relmd_bytes = NULL;
+	AsReleaseList *releases = as_component_get_releases_plain (cpt);
 
 	/* download external release metadata or fetch local release data */
-	if (as_component_get_releases_kind (cpt) == AS_RELEASES_KIND_EXTERNAL) {
+	if (as_release_list_get_kind (releases) == AS_RELEASE_LIST_KIND_EXTERNAL) {
 		g_autofree gchar *relmd_uri = NULL;
 
-		g_ptr_array_set_size (as_component_get_releases (cpt), 0);
-		if (allow_net && as_component_get_releases_url (cpt) != NULL) {
+		as_release_list_clear (releases);
+		if (allow_net && as_release_list_get_url (releases) != NULL) {
 			/* get the release data from a network location */
-			const gchar *releases_url = as_component_get_releases_url (cpt);
+			const gchar *releases_url = as_release_list_get_url (releases);
 
 			relmd_bytes = as_curl_download_bytes (acurl, releases_url, &local_error);
 			if (relmd_bytes == NULL) {
-				asc_result_add_hint (cres, NULL,
+				asc_result_add_hint (cres,
+						     NULL,
 						     "metainfo-releases-download-failed",
-						     "url", releases_url,
-						     "msg", local_error->message,
+						     "url",
+						     releases_url,
+						     "msg",
+						     local_error->message,
 						     NULL);
 				goto out;
 			}
@@ -174,28 +190,36 @@ asc_process_metainfo_releases (AscResult *cres,
 			g_autofree gchar *relfile_name = NULL;
 			g_autofree gchar *tmp = NULL;
 
-			relfile_name = g_strconcat (as_component_get_id (cpt), ".releases.xml", NULL);
+			relfile_name = g_strconcat (as_component_get_id (cpt),
+						    ".releases.xml",
+						    NULL);
 			tmp = g_path_get_dirname (mi_filename);
 			relfile_path = g_build_filename (tmp, "releases", relfile_name, NULL);
 
 			relmd_bytes = asc_unit_read_data (unit, relfile_path, &local_error);
 			if (relmd_bytes == NULL) {
-				asc_result_add_hint (cres, NULL,
+				asc_result_add_hint (cres,
+						     NULL,
 						     "file-read-error",
-						     "fname", relfile_path,
-						     "msg", local_error->message,
+						     "fname",
+						     relfile_path,
+						     "msg",
+						     local_error->message,
 						     NULL);
 				goto out;
 			}
 			relmd_uri = g_steal_pointer (&relfile_path);
 		}
 
-		if (!as_component_load_releases_from_bytes (cpt, relmd_bytes, &local_error)) {
-			asc_result_add_hint (cres, NULL,
-						"metainfo-releases-read-failed",
-						"path", relmd_uri,
-						"msg", local_error->message,
-						NULL);
+		if (!as_release_list_load_from_bytes (releases, NULL, relmd_bytes, &local_error)) {
+			asc_result_add_hint (cres,
+					     NULL,
+					     "metainfo-releases-read-failed",
+					     "path",
+					     relmd_uri,
+					     "msg",
+					     local_error->message,
+					     NULL);
 			goto out;
 		}
 	}
@@ -204,9 +228,8 @@ asc_process_metainfo_releases (AscResult *cres,
 	 * since releases are sorted with the newest one at the top, we will only
 	 * remove the older ones. */
 	if (as_component_get_kind (cpt) != AS_COMPONENT_KIND_OPERATING_SYSTEM) {
-		GPtrArray *releases = as_component_get_releases (cpt);
-		if (releases->len > MAX_RELEASE_INFO_COUNT)
-			g_ptr_array_set_size (releases, MAX_RELEASE_INFO_COUNT);
+		if (as_release_list_len (releases) > MAX_RELEASE_INFO_COUNT)
+			as_release_list_set_size (releases, MAX_RELEASE_INFO_COUNT);
 	}
 
 out:
@@ -240,22 +263,24 @@ asc_validate_metainfo_data_for_component (AscResult *cres,
 	gpointer hkey, hvalue;
 
 	/* don't check web URLs for validity, we catch those issues differently */
-	as_validator_set_check_urls (validator, FALSE);
+	as_validator_set_allow_net (validator, FALSE);
 
-	/* remove issues from a potential previous use of this validator */
-	as_validator_clear_issues (validator);
+	/* remove release data from a potential previous use of this validator */
 	as_validator_clear_release_data (validator);
 
 	/* add release data if we have any */
 	if (relmd_bytes != NULL) {
 		g_autoptr(GError) tmp_error = NULL;
-		g_autofree gchar *release_name = g_strconcat (as_component_get_id (cpt), ".releases.xml", NULL);
+		g_autofree gchar *release_name = g_strconcat (as_component_get_id (cpt),
+							      ".releases.xml",
+							      NULL);
 		if (!as_validator_add_release_bytes (validator,
 						     release_name,
 						     relmd_bytes,
 						     &tmp_error))
 			g_warning ("Failed to add release metadata for %s: %s",
-				   as_component_get_id (cpt), tmp_error->message);
+				   as_component_get_id (cpt),
+				   tmp_error->message);
 	}
 
 	/* validate */
@@ -265,10 +290,10 @@ asc_validate_metainfo_data_for_component (AscResult *cres,
 	issues_files = as_validator_get_issues_per_file (validator);
 	g_hash_table_iter_init (&hiter, issues_files);
 	while (g_hash_table_iter_next (&hiter, &hkey, &hvalue)) {
-		const gchar *filename = (const gchar*) hkey;
-		const GPtrArray *issues = (const GPtrArray*) hvalue;
+		const gchar *filename = (const gchar *) hkey;
+		const GPtrArray *issues = (const GPtrArray *) hvalue;
 
-		if (filename == NULL)
+		if (as_is_empty (filename))
 			filename = mi_basename;
 
 		for (guint i = 0; i < issues->len; i++) {
@@ -276,19 +301,19 @@ asc_validate_metainfo_data_for_component (AscResult *cres,
 			g_autofree gchar *location = NULL;
 			glong line;
 			const gchar *issue_hint;
-			AsValidatorIssue *issue = AS_VALIDATOR_ISSUE (g_ptr_array_index (issues, i));
+			AsValidatorIssue *issue = AS_VALIDATOR_ISSUE (
+			    g_ptr_array_index (issues, i));
 
 			/* we have a special hint tag for legacy metadata,
-			* with its proper "error" priority */
-			if (g_strcmp0 (as_validator_issue_get_tag (issue), "metainfo-ancient") == 0) {
+			 * with its proper "error" priority */
+			if (g_strcmp0 (as_validator_issue_get_tag (issue), "metainfo-ancient") ==
+			    0) {
 				asc_result_add_hint_simple (cres, cpt, "ancient-metadata");
 				continue;
 			}
 
 			/* create a tag for asgen out of the AppStream validator tag by prefixing it */
-			asv_tag = g_strconcat ("asv-",
-					as_validator_issue_get_tag (issue),
-					NULL);
+			asv_tag = g_strconcat ("asv-", as_validator_issue_get_tag (issue), NULL);
 
 			line = as_validator_issue_get_line (issue);
 			if (line >= 0)
@@ -302,10 +327,13 @@ asc_validate_metainfo_data_for_component (AscResult *cres,
 			issue_hint = as_validator_issue_get_hint (issue);
 			if (issue_hint == NULL)
 				issue_hint = "";
-			asc_result_add_hint (cres, cpt,
+			asc_result_add_hint (cres,
+					     cpt,
 					     asv_tag,
-					     "location", location,
-					     "hint", issue_hint,
+					     "location",
+					     location,
+					     "hint",
+					     issue_hint,
 					     NULL);
 		}
 	}
@@ -327,13 +355,15 @@ asc_validate_metainfo_data_for_component (AscResult *cres,
  * Returns: (nullable) (transfer full): A new #AsComponent or reference to the existing #AsComponent passed as parameter in case
  *                                      we parsed anything. %NULL if we refused to accept this data.
  */
-AsComponent*
+AsComponent *
 asc_parse_desktop_entry_data (AscResult *cres,
 			      AsComponent *cpt,
-			      GBytes *bytes, const gchar *de_basename,
+			      GBytes *bytes,
+			      const gchar *de_basename,
 			      gboolean ignore_nodisplay,
 			      AsFormatVersion fversion,
-			      AscTranslateDesktopTextFn de_l10n_fn, gpointer user_data)
+			      AscTranslateDesktopTextFn de_l10n_fn,
+			      gpointer user_data)
 {
 	g_autoptr(AsComponent) ncpt = NULL;
 	g_autoptr(GPtrArray) issues = NULL;
@@ -365,10 +395,13 @@ asc_parse_desktop_entry_data (AscResult *cres,
 
 	/* sanity check */
 	if (data_len == 0) {
-		asc_result_add_hint_by_cid (cres, de_basename,
+		asc_result_add_hint_by_cid (cres,
+					    de_basename,
 					    "desktop-file-error",
-					    "msg", "Desktop file was empty or nonexistent. "
-						   "Please ensure that it isn't a symbolic link to contents of a different package.",
+					    "msg",
+					    "Desktop file was empty or nonexistent. "
+					    "Please ensure that it isn't a symbolic link to "
+					    "contents of a different package.",
 					    NULL);
 		return NULL;
 	}
@@ -384,9 +417,11 @@ asc_parse_desktop_entry_data (AscResult *cres,
 					   user_data,
 					   &error);
 	if (error != NULL) {
-		asc_result_add_hint_by_cid (cres, de_basename,
+		asc_result_add_hint_by_cid (cres,
+					    de_basename,
 					    "desktop-file-error",
-					    "msg", error->message,
+					    "msg",
+					    error->message,
 					    NULL);
 		return NULL;
 	}
@@ -436,17 +471,18 @@ asc_parse_desktop_entry_data (AscResult *cres,
 			/* these tags get special treatment with links & co */
 			asv_tag = g_strdup (orig_tag);
 		} else {
-			asv_tag = g_strconcat ("asv-",
-						orig_tag,
-						NULL);
+			asv_tag = g_strconcat ("asv-", orig_tag, NULL);
 		}
 		issue_hint = as_validator_issue_get_hint (issue);
 		if (issue_hint == NULL)
 			issue_hint = "";
-		asc_result_add_hint (cres, ncpt,
+		asc_result_add_hint (cres,
+				     ncpt,
 				     asv_tag,
-				     "location", de_basename,
-				     "hint", issue_hint,
+				     "location",
+				     de_basename,
+				     "hint",
+				     issue_hint,
 				     NULL);
 	}
 
