@@ -106,11 +106,12 @@ asc_extract_video_info (AscResult *cres, AsComponent *cpt, const gchar *vid_fnam
 					vid_fname,
 					NULL };
 
-	vinfo = asc_video_info_new ();
-	if (vid_fname == NULL)
-		return vinfo;
 	if (asc_globals_get_ffprobe_binary () == NULL)
 		return NULL;
+	if (vid_fname == NULL)
+		return NULL;
+
+	vinfo = asc_video_info_new ();
 	vid_basename = g_path_get_basename (vid_fname);
 
 	ret = g_spawn_sync (NULL, /* working directory */
@@ -449,6 +450,21 @@ asc_process_screenshot_images_lang (AscResult *cres,
 	if (max_size_bytes == 0)
 		store_screenshots = FALSE;
 
+	{
+		AscImageFormat image_format = asc_image_format_from_filename (orig_img_url);
+
+		/* we do not allow vector graphics as screenshots */
+		if (image_format == ASC_IMAGE_FORMAT_SVG || image_format == ASC_IMAGE_FORMAT_SVGZ) {
+			asc_result_add_hint (cres,
+					     cpt,
+					     "screenshot-image-is-svg",
+					     "url",
+					     orig_img_url,
+					     NULL);
+			return FALSE;
+		}
+	}
+
 	/* download our image */
 	img_bytes = as_curl_download_bytes (acurl, orig_img_url, &error);
 	if (img_bytes == NULL) {
@@ -516,9 +532,10 @@ asc_process_screenshot_images_lang (AscResult *cres,
 		/* save the source screenshot as PNG image */
 		src_image = asc_image_new_from_data (img_data,
 						     img_data_len,
-						     0,	    /* destination size */
-						     FALSE, /* compressed */
+						     -1, /* destination width */
+						     -1, /* destination height */
 						     ASC_IMAGE_LOAD_FLAG_NONE,
+						     ASC_IMAGE_FORMAT_UNKNOWN,
 						     &error);
 		if (error != NULL) {
 			g_autofree gchar *msg = g_strdup_printf (
@@ -606,9 +623,10 @@ asc_process_screenshot_images_lang (AscResult *cres,
 
 		thumb = asc_image_new_from_data (img_data,
 						 img_data_len,
-						 0,	/* destination size */
-						 FALSE, /* compressed */
+						 -1, /* destination width */
+						 -1, /* destination height */
 						 ASC_IMAGE_LOAD_FLAG_NONE,
+						 ASC_IMAGE_FORMAT_UNKNOWN,
 						 &error);
 		if (error != NULL) {
 			g_autofree gchar *msg = g_strdup_printf (
