@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2018 Richard Hughes <richard@hughsie.com>
- * Copyright (C) 2018-2022 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2018-2024 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -36,12 +36,11 @@
 #include "as-context-private.h"
 
 typedef struct {
-	gchar		*kind;
-	GHashTable	*name;
-	GHashTable	*description;
+	gchar *kind;
+	GHashTable *name;
+	GHashTable *description;
 
-	AsContext	*context;
-	GRefString	*active_locale_override;
+	AsContext *context;
 } AsAgreementSectionPrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE (AsAgreementSection, as_agreement_section, G_TYPE_OBJECT)
@@ -58,7 +57,6 @@ as_agreement_section_finalize (GObject *object)
 	g_hash_table_unref (priv->name);
 	g_hash_table_unref (priv->description);
 
-	as_ref_string_release (priv->active_locale_override);
 	if (priv->context != NULL)
 		g_object_unref (priv->context);
 
@@ -70,10 +68,12 @@ as_agreement_section_init (AsAgreementSection *agreement_section)
 {
 	AsAgreementSectionPrivate *priv = GET_PRIVATE (agreement_section);
 
-	priv->name = g_hash_table_new_full (g_str_hash, g_str_equal,
+	priv->name = g_hash_table_new_full (g_str_hash,
+					    g_str_equal,
 					    (GDestroyNotify) as_ref_string_release,
 					    g_free);
-	priv->description = g_hash_table_new_full (g_str_hash, g_str_equal,
+	priv->description = g_hash_table_new_full (g_str_hash,
+						   g_str_equal,
 						   (GDestroyNotify) as_ref_string_release,
 						   g_free);
 }
@@ -95,7 +95,7 @@ as_agreement_section_class_init (AsAgreementSectionClass *klass)
  *
  * Since: 0.12.1
  **/
-const gchar*
+const gchar *
 as_agreement_section_get_kind (AsAgreementSection *agreement_section)
 {
 	AsAgreementSectionPrivate *priv = GET_PRIVATE (agreement_section);
@@ -130,14 +130,11 @@ as_agreement_section_set_kind (AsAgreementSection *agreement_section, const gcha
  *
  * Since: 0.12.1
  **/
-const gchar*
+const gchar *
 as_agreement_section_get_name (AsAgreementSection *agreement_section)
 {
 	AsAgreementSectionPrivate *priv = GET_PRIVATE (agreement_section);
-	return as_context_localized_ht_get (priv->context,
-					    priv->name,
-					    priv->active_locale_override,
-					    AS_VALUE_FLAG_NONE);
+	return as_context_localized_ht_get (priv->context, priv->name, NULL /* locale override */);
 }
 
 /**
@@ -152,13 +149,11 @@ as_agreement_section_get_name (AsAgreementSection *agreement_section)
  **/
 void
 as_agreement_section_set_name (AsAgreementSection *agreement_section,
-			       const gchar *name, const gchar *locale)
+			       const gchar *name,
+			       const gchar *locale)
 {
 	AsAgreementSectionPrivate *priv = GET_PRIVATE (agreement_section);
-	as_context_localized_ht_set (priv->context,
-				     priv->name,
-				     name,
-				     locale);
+	as_context_localized_ht_set (priv->context, priv->name, name, locale);
 }
 
 /**
@@ -171,14 +166,13 @@ as_agreement_section_set_name (AsAgreementSection *agreement_section,
  *
  * Since: 0.12.1
  **/
-const gchar*
+const gchar *
 as_agreement_section_get_description (AsAgreementSection *agreement_section)
 {
 	AsAgreementSectionPrivate *priv = GET_PRIVATE (agreement_section);
 	return as_context_localized_ht_get (priv->context,
 					    priv->description,
-					    priv->active_locale_override,
-					    AS_VALUE_FLAG_NONE);
+					    NULL /* locale override */);
 }
 
 /**
@@ -193,25 +187,25 @@ as_agreement_section_get_description (AsAgreementSection *agreement_section)
  **/
 void
 as_agreement_section_set_description (AsAgreementSection *agreement_section,
-				      const gchar *desc, const gchar *locale)
+				      const gchar *desc,
+				      const gchar *locale)
 {
 	AsAgreementSectionPrivate *priv = GET_PRIVATE (agreement_section);
-	as_context_localized_ht_set (priv->context,
-				     priv->description,
-				     desc,
-				     locale);
+	as_context_localized_ht_set (priv->context, priv->description, desc, locale);
 }
 
 /**
  * as_agreement_section_get_context:
  * @agreement_section: An instance of #AsAgreementSection.
  *
- * Returns: the #AsContext associated with this release.
+ * Returns the #AsContext associated with this section.
  * This function may return %NULL if no context is set.
  *
+ * Returns: (transfer none) (nullable): the #AsContext used by this agreement section.
+ *
  * Since: 0.12.1
  */
-AsContext*
+AsContext *
 as_agreement_section_get_context (AsAgreementSection *agreement_section)
 {
 	AsAgreementSectionPrivate *priv = GET_PRIVATE (agreement_section);
@@ -234,54 +228,7 @@ as_agreement_section_set_context (AsAgreementSection *agreement_section, AsConte
 	AsAgreementSectionPrivate *priv = GET_PRIVATE (agreement_section);
 	if (priv->context != NULL)
 		g_object_unref (priv->context);
-	priv->context = g_object_ref (context);
-	as_ref_string_assign_safe (&priv->active_locale_override, NULL);
-}
-
-/**
- * as_agreement_section_get_active_locale:
- *
- * Get the current active locale, which
- * is used to get localized messages.
- */
-const gchar*
-as_agreement_section_get_active_locale (AsAgreementSection *agreement_section)
-{
-	AsAgreementSectionPrivate *priv = GET_PRIVATE (agreement_section);
-	const gchar *locale;
-
-	/* return context locale, if the locale isn't explicitly overridden for this component */
-	if ((priv->context != NULL) && (priv->active_locale_override == NULL)) {
-		locale = as_context_get_locale (priv->context);
-	} else {
-		locale = priv->active_locale_override;
-	}
-
-	if (locale == NULL)
-		return "C";
-	else
-		return locale;
-}
-
-/**
- * as_agreement_section_set_active_locale:
- * @agreement_section: an #AsAgreement
- * @locale: (nullable): a POSIX or BCP47 locale, or %NULL. e.g. "de_DE"
- *
- * Set the current active locale, which
- * is used to get localized messages.
- */
-void
-as_agreement_section_set_active_locale (AsAgreementSection *agreement_section, const gchar *locale)
-{
-	AsAgreementSectionPrivate *priv = GET_PRIVATE (agreement_section);
-
-	if (as_locale_is_bcp47 (locale)) {
-		as_ref_string_assign_safe (&priv->active_locale_override, locale);
-	} else {
-		g_autofree gchar *bcp47 = as_utils_posix_locale_to_bcp47 (locale);
-		as_ref_string_assign_safe (&priv->active_locale_override, bcp47);
-	}
+	priv->context = context == NULL ? NULL : g_object_ref (context);
 }
 
 /**
@@ -294,7 +241,10 @@ as_agreement_section_set_active_locale (AsAgreementSection *agreement_section, c
  * Loads data from an XML node.
  **/
 gboolean
-as_agreement_section_load_from_xml (AsAgreementSection *agreement_section, AsContext *ctx, xmlNode *node, GError **error)
+as_agreement_section_load_from_xml (AsAgreementSection *agreement_section,
+				    AsContext *ctx,
+				    xmlNode *node,
+				    GError **error)
 {
 	xmlNode *iter;
 	gchar *prop;
@@ -315,7 +265,7 @@ as_agreement_section_load_from_xml (AsAgreementSection *agreement_section, AsCon
 
 		lang = as_xml_get_node_locale_match (ctx, iter);
 
-		if (g_strcmp0 ((gchar*) iter->name, "name") == 0) {
+		if (g_strcmp0 ((gchar *) iter->name, "name") == 0) {
 			g_autofree gchar *content = NULL;
 
 			content = as_xml_get_node_value (iter);
@@ -327,12 +277,14 @@ as_agreement_section_load_from_xml (AsAgreementSection *agreement_section, AsCon
 			continue;
 		}
 
-		if (g_strcmp0 ((gchar*) iter->name, "description") == 0) {
+		if (g_strcmp0 ((gchar *) iter->name, "description") == 0) {
 			g_autofree gchar *content = NULL;
 
 			content = as_xml_dump_node_children (iter);
 			if (lang != NULL)
-				as_agreement_section_set_description (agreement_section, content, lang);
+				as_agreement_section_set_description (agreement_section,
+								      content,
+								      lang);
 
 			continue;
 		}
@@ -350,7 +302,9 @@ as_agreement_section_load_from_xml (AsAgreementSection *agreement_section, AsCon
  * Serializes the data to an XML node.
  **/
 void
-as_agreement_section_to_xml_node (AsAgreementSection *agreement_section, AsContext *ctx, xmlNode *root)
+as_agreement_section_to_xml_node (AsAgreementSection *agreement_section,
+				  AsContext *ctx,
+				  xmlNode *root)
 {
 	AsAgreementSectionPrivate *priv = GET_PRIVATE (agreement_section);
 	xmlNode *asnode;
@@ -372,25 +326,30 @@ as_agreement_section_to_xml_node (AsAgreementSection *agreement_section, AsConte
  * Loads data from a YAML field.
  **/
 gboolean
-as_agreement_section_load_from_yaml (AsAgreementSection *agreement_section, AsContext *ctx, GNode *node, GError **error)
+as_agreement_section_load_from_yaml (AsAgreementSection *agreement_section,
+				     AsContext *ctx,
+				     struct fy_node *node,
+				     GError **error)
 {
 	AsAgreementSectionPrivate *priv = GET_PRIVATE (agreement_section);
-	GNode *n;
 
 	/* propagate context */
 	as_agreement_section_set_context (agreement_section, ctx);
 
-	for (n = node->children; n != NULL; n = n->next) {
-		const gchar *key = as_yaml_node_get_key (n);
+	AS_YAML_MAPPING_FOREACH (pair, node) {
+		const gchar *key = as_yaml_node_get_key0 (pair);
 
 		if (g_strcmp0 (key, "type") == 0) {
-			as_agreement_section_set_kind (agreement_section, as_yaml_node_get_value (n));
+			as_agreement_section_set_kind (agreement_section,
+						       as_yaml_node_get_value0 (pair));
 		} else if (g_strcmp0 (key, "name") == 0) {
-			as_yaml_set_localized_table (ctx, n, priv->name);
+			as_yaml_set_localized_table (ctx, fy_node_pair_value (pair), priv->name);
 		} else if (g_strcmp0 (key, "description") == 0) {
-			as_yaml_set_localized_table (ctx, n, priv->description);
+			as_yaml_set_localized_table (ctx,
+						     fy_node_pair_value (pair),
+						     priv->description);
 		} else {
-			as_yaml_print_unknown ("agreement_section", key);
+			as_yaml_print_unknown ("agreement_section", key, -1);
 		}
 	}
 
@@ -406,7 +365,9 @@ as_agreement_section_load_from_yaml (AsAgreementSection *agreement_section, AsCo
  * Emit YAML data for this object.
  **/
 void
-as_agreement_section_emit_yaml (AsAgreementSection *agreement_section, AsContext *ctx, yaml_emitter_t *emitter)
+as_agreement_section_emit_yaml (AsAgreementSection *agreement_section,
+				AsContext *ctx,
+				struct fy_emitter *emitter)
 {
 	AsAgreementSectionPrivate *priv = GET_PRIVATE (agreement_section);
 
@@ -417,14 +378,10 @@ as_agreement_section_emit_yaml (AsAgreementSection *agreement_section, AsContext
 	as_yaml_emit_entry (emitter, "type", priv->kind);
 
 	/* name */
-	as_yaml_emit_localized_entry (emitter,
-				      "name",
-				      priv->name);
+	as_yaml_emit_localized_entry (emitter, "name", priv->name);
 
 	/* description */
-	as_yaml_emit_long_localized_entry (emitter,
-					   "description",
-					   priv->description);
+	as_yaml_emit_long_localized_entry (emitter, "description", priv->description);
 
 	/* end mapping for the agreement */
 	as_yaml_mapping_end (emitter);
