@@ -34,11 +34,11 @@ gboolean	       as_artifact_load_from_xml (AsArtifact *artifact,
 						  GError    **error);
 void	 as_artifact_to_xml_node (AsArtifact *artifact, AsContext *ctx, xmlNode *root);
 
-gboolean as_artifact_load_from_yaml (AsArtifact *artifact,
-				     AsContext	*ctx,
-				     GNode	*node,
-				     GError    **error);
-void	 as_artifact_emit_yaml (AsArtifact *artifact, AsContext *ctx, yaml_emitter_t *emitter);
+gboolean as_artifact_load_from_yaml (AsArtifact	    *artifact,
+				     AsContext	    *ctx,
+				     struct fy_node *node,
+				     GError	   **error);
+void	 as_artifact_emit_yaml (AsArtifact *artifact, AsContext *ctx, struct fy_emitter *emitter);
 
 #pragma GCC visibility pop
 G_END_DECLS
