@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2014-2022 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2014-2024 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -28,22 +28,15 @@
 G_BEGIN_DECLS
 #pragma GCC visibility push(hidden)
 
-gboolean	as_image_load_from_xml (AsImage *image,
-					AsContext *ctx,
-					xmlNode *node,
-					GError **error);
-void		as_image_to_xml_node (AsImage *image,
-				       AsContext *ctx,
-				       xmlNode *root);
+gboolean as_image_load_from_xml (AsImage *image, AsContext *ctx, xmlNode *node, GError **error);
+void	 as_image_to_xml_node (AsImage *image, AsContext *ctx, xmlNode *root);
 
-gboolean	as_image_load_from_yaml (AsImage *image,
-					  AsContext *ctx,
-					  GNode *node,
-					  AsImageKind kind,
-					  GError **error);
-void		as_image_emit_yaml (AsImage *image,
-					AsContext *ctx,
-					yaml_emitter_t *emitter);
+gboolean as_image_load_from_yaml (AsImage	 *image,
+				  AsContext	 *ctx,
+				  struct fy_node *node,
+				  AsImageKind	  kind,
+				  GError	**error);
+void	 as_image_emit_yaml (AsImage *image, AsContext *ctx, struct fy_emitter *emitter);
 
 #pragma GCC visibility pop
 G_END_DECLS
