@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2019-2022 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2019-2024 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -31,11 +31,10 @@
 #include "config.h"
 #include "as-issue-private.h"
 
-typedef struct
-{
-	AsIssueKind		 kind;
-	gchar			*id;
-	gchar			*url;
+typedef struct {
+	AsIssueKind kind;
+	gchar *id;
+	gchar *url;
 } AsIssuePrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE (AsIssue, as_issue, G_TYPE_OBJECT)
@@ -50,7 +49,7 @@ G_DEFINE_TYPE_WITH_PRIVATE (AsIssue, as_issue, G_TYPE_OBJECT)
  *
  * Returns: string version of @kind
  **/
-const gchar*
+const gchar *
 as_issue_kind_to_string (AsIssueKind kind)
 {
 	if (kind == AS_ISSUE_KIND_GENERIC)
@@ -143,7 +142,7 @@ as_issue_set_kind (AsIssue *issue, AsIssueKind kind)
  *
  * Returns: the ID.
  **/
-const gchar*
+const gchar *
 as_issue_get_id (AsIssue *issue)
 {
 	AsIssuePrivate *priv = GET_PRIVATE (issue);
@@ -174,14 +173,15 @@ as_issue_set_id (AsIssue *issue, const gchar *id)
  *
  * Returns: the URL.
  **/
-const gchar*
+const gchar *
 as_issue_get_url (AsIssue *issue)
 {
 	AsIssuePrivate *priv = GET_PRIVATE (issue);
 
 	/* we can synthesize an URL if the issue type is a CVE entry */
 	if ((priv->url == NULL) && (priv->kind == AS_ISSUE_KIND_CVE) && (priv->id != NULL))
-		priv->url = g_strdup_printf ("https://cve.mitre.org/cgi-bin/cvename.cgi?name=%s", priv->id);
+		priv->url = g_strdup_printf ("https://cve.mitre.org/cgi-bin/cvename.cgi?name=%s",
+					     priv->id);
 
 	return priv->url;
 }
@@ -270,13 +270,13 @@ as_issue_to_xml_node (AsIssue *issue, AsContext *ctx, xmlNode *root)
  * Loads data from a YAML field.
  **/
 gboolean
-as_issue_load_from_yaml (AsIssue *issue, AsContext *ctx, GNode *node, GError **error)
+as_issue_load_from_yaml (AsIssue *issue, AsContext *ctx, struct fy_node *node, GError **error)
 {
 	AsIssuePrivate *priv = GET_PRIVATE (issue);
 
-	for (GNode *n = node->children; n != NULL; n = n->next) {
-		const gchar *key = as_yaml_node_get_key (n);
-		const gchar *value = as_yaml_node_get_value (n);
+	AS_YAML_MAPPING_FOREACH (pair, node) {
+		const gchar *key = as_yaml_node_get_key0 (pair);
+		const gchar *value = as_yaml_node_get_value0 (pair);
 
 		if (G_UNLIKELY (value == NULL))
 			continue; /* there should be no key without value */
@@ -293,7 +293,7 @@ as_issue_load_from_yaml (AsIssue *issue, AsContext *ctx, GNode *node, GError **e
 			priv->url = g_strdup (value);
 
 		} else {
-			as_yaml_print_unknown ("issue", key);
+			as_yaml_print_unknown ("issue", key, -1);
 		}
 	}
 
@@ -309,7 +309,7 @@ as_issue_load_from_yaml (AsIssue *issue, AsContext *ctx, GNode *node, GError **e
  * Emit YAML data for this object.
  **/
 void
-as_issue_emit_yaml (AsIssue *issue, AsContext *ctx, yaml_emitter_t *emitter)
+as_issue_emit_yaml (AsIssue *issue, AsContext *ctx, struct fy_emitter *emitter)
 {
 	AsIssuePrivate *priv = GET_PRIVATE (issue);
 
@@ -339,7 +339,7 @@ as_issue_emit_yaml (AsIssue *issue, AsContext *ctx, yaml_emitter_t *emitter)
  *
  * Returns: (transfer full): an #AsIssue
  **/
-AsIssue*
+AsIssue *
 as_issue_new (void)
 {
 	AsIssue *issue;
