@@ -37,11 +37,11 @@ gboolean as_release_load_from_xml (AsRelease *release,
 				   GError   **error);
 void	 as_release_to_xml_node (AsRelease *release, AsContext *ctx, xmlNode *root);
 
-gboolean as_release_load_from_yaml (AsRelease *release,
-				    AsContext *ctx,
-				    GNode     *node,
-				    GError   **error);
-void	 as_release_emit_yaml (AsRelease *release, AsContext *ctx, yaml_emitter_t *emitter);
+gboolean as_release_load_from_yaml (AsRelease	   *release,
+				    AsContext	   *ctx,
+				    struct fy_node *node,
+				    GError	  **error);
+void	 as_release_emit_yaml (AsRelease *release, AsContext *ctx, struct fy_emitter *emitter);
 
 AS_END_PRIVATE_DECLS
 
