@@ -36,7 +36,7 @@ typedef struct {
 } AsValidatorIssueTag;
 
 /* clang-format off */
-AsValidatorIssueTag as_validator_issue_tag_list[] =  {
+static AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	{ "type-property-required",
 	  AS_ISSUE_SEVERITY_ERROR,
 	  N_("This tag requires a type property.")
@@ -98,6 +98,17 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	  N_("The description contains a web URL in plain text. This is not allowed, please use the <url/> tag instead to share links.")
 	},
 
+	{ "description-no-valid-content",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  N_("The description element does not contain any valid content (paragraphs, enumerations, etc.).")
+	},
+
+	{ "description-spurious-text",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  N_("The description element contains raw text that is not in any paragraph or other permitted tag. "
+	     "This is not allowed and the additional text may be ignored by parsers or raise errors.")
+	},
+
 	{ "tag-not-translatable",
 	  AS_ISSUE_SEVERITY_ERROR,
 	  N_("This tag is not translatable.")
@@ -690,11 +701,17 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	  N_("It is recommended to add a long description to this component to present it better to users."),
 	},
 
-	{ "generic-description-missing",
+	{ "description-missing",
 	  AS_ISSUE_SEVERITY_PEDANTIC,
 	  N_("This generic component is missing a long description. It may be useful to add one."),
 	},
 
+	{ "untranslated-description-missing",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  N_("The component is missing an untranslated long description, but has a translated one for the English locale. "
+	     "You need to provide a locale-less description in English as translation template."),
+	},
+
 	{ "desktop-app-launchable-missing",
 	  AS_ISSUE_SEVERITY_ERROR,
 	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
@@ -1041,7 +1058,7 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 
 	{ "runtime-no-provides",
 	  AS_ISSUE_SEVERITY_PEDANTIC,
-	  N_("Since a `runtime` component is comprised of multiple other software components, their component-IDs may be listed in a `<provides/>` section for this runtime.")
+	  N_("Since a `runtime` component consists of multiple other software components, their component-IDs may be listed in a `<provides/>` section for this runtime.")
 	},
 
 	{ "unknown-provides-item-type",
