@@ -27,7 +27,7 @@ eatmydata apt-get install -yq --no-install-recommends \
     itstool \
     libglib2.0-dev \
     libxml2-dev \
-    libyaml-dev \
+    libfyaml-dev \
     libxmlb-dev \
     liblzma-dev \
     libzstd-dev \
@@ -43,15 +43,8 @@ eatmydata apt-get install -yq --no-install-recommends \
     gperf \
     valac
 
-# install build dependencies for libappstream-compose
-. /etc/os-release
-if [ "$ID" = "ubuntu" ]; then
-    gdk_pixbuf_dep="libgdk-pixbuf2.0-dev"
-else
-    gdk_pixbuf_dep="libgdk-pixbuf-2.0-dev"
-fi;
 eatmydata apt-get install -yq --no-install-recommends \
-    $gdk_pixbuf_dep \
+    libgdk-pixbuf-2.0-dev \
     librsvg2-dev \
     libcairo2-dev \
     libfontconfig-dev \
