@@ -20,6 +20,8 @@
 
 #include <config.h>
 #include <glib.h>
+#include <locale.h>
+
 #include "appstream.h"
 #include "as-component-private.h"
 #include "as-component-box-private.h"
@@ -916,8 +918,10 @@ test_system_info (void)
 	g_assert_cmpstr (as_system_info_get_os_id (sysinfo), ==, "debian");
 	g_assert_cmpstr (as_system_info_get_os_cid (sysinfo), ==, "org.debian.debian");
 
+#ifndef G_OS_WIN32
 	g_assert_nonnull (as_system_info_get_kernel_name (sysinfo));
 	g_assert_nonnull (as_system_info_get_kernel_version (sysinfo));
+#endif
 
 	g_assert_cmpint (as_system_info_get_memory_total (sysinfo), >=, 128);
 
@@ -1242,6 +1246,8 @@ main (int argc, char **argv)
 {
 	int ret;
 
+	setlocale (LC_ALL, "");
+
 	if (argc == 0) {
 		g_error ("No test directory specified!");
 		return 1;
