@@ -19,6 +19,8 @@
  */
 
 #include <glib.h>
+#include <locale.h>
+
 #include "appstream.h"
 #include "as-news-convert.h"
 #include "as-utils-private.h"
@@ -59,14 +61,14 @@ static void
 test_readwrite_yaml_news (void)
 {
 	static const gchar *yaml_news_data = "---\n"
-					     "Version: 1.2\n"
+					     "Version: '1.2'\n"
 					     "Date: 2019-04-18\n"
 					     "Type: development\n"
 					     "Description:\n"
 					     "- Improved A & X\n"
 					     "- Fixed B\n"
 					     "---\n"
-					     "Version: 1.1\n"
+					     "Version: '1.1'\n"
 					     "Date: 2019-04-12\n"
 					     "Description: |-\n"
 					     "  A freeform description text.\n"
@@ -78,7 +80,7 @@ test_readwrite_yaml_news (void)
 					     "  \n"
 					     "  Third paragraph.\n"
 					     "---\n"
-					     "Version: 1.0\n"
+					     "Version: '1.0'\n"
 					     "Date: 2019-02-24\n"
 					     "Description:\n"
 					     "- Introduced feature A\n"
@@ -463,6 +465,8 @@ main (int argc, char **argv)
 {
 	int ret;
 
+	setlocale (LC_ALL, "");
+
 	if (argc == 0) {
 		g_error ("No test directory specified!");
 		return 1;
